

## Bodo Winter, Analysis of Korean Politeness Perception data, Experiment 1
## by Lucien Brown, Kaori Idemaru, Bodo Winter and Sven Grawunder
## Created: February 23, 2013
## Edited: August 7, 2013
## Additional tests after submission: October 29, 2013
## Completely renewed after reviewer feedback: January 7, 2014



################----------------------------------------------------------------------------------------------------
################ Analysis of Experiment 1: Preparation
################----------------------------------------------------------------------------------------------------

## Load in my common functions, set up working directory and load in data:

source("/Users/teeniematlock/Desktop/statistics/scripts/bodos_functions.R")
setwd("/Users/teeniematlock/Desktop/research/politeness/politeness_perception_study/")
xdata = read.csv("all_E1AB.csv",comment.char="")



## Because some Korean and English participants have the same subject ID, create a unique subject identifier, using the
## language name:

xdata$sub_uniqID = paste(xdata$subject,xdata$language,sep="/")



## Exclude non-native speakers from the English sample:

non_natives = paste(c(8, 14, 19),"english",sep="/")
xdata = xdata[is.na(match(xdata$sub_uniqID,non_natives)),]



## Exclude Korean subject 20, since he also participated in the production experiment and listened to his own voice!:

xdata = xdata[xdata$sub_uniqID!="20/korean",]



## Check aberrant reaction times:

length(which(xdata$RT>5000))						# 82 data points that are above 5 s
length(which(xdata$RT>5000)) / nrow(xdata)			# ~1.3% of the total data



## Create two datasets... one with all RT... one with all RT < 5000
## (this will be useful later to see whether the truncation did or did not affect the results):

xdata.orig = xdata
xdata = xdata[which(xdata$RT<5000),]



## Log-transform reaction times:

xdata$logRT = log(xdata$RT + 1)
xdata.orig$logRT = log(xdata.orig$RT + 1)



## Create Korean and English subsets to quickly check summary stats:

kor = xdata[xdata$language=="korean",]
eng = xdata[xdata$language=="english",]



## Find No. of males and females for total, for Korean and English... do the same for age:

table(kor[match(unique(kor$sub_uniqID),kor$sub_uniqID),]$sex)	# Korean: 8 female, 12 male
table(eng[match(unique(eng$sub_uniqID),eng$sub_uniqID),]$sex)	# English: 12 female, 8 male
mean(kor[match(unique(kor$sub_uniqID),kor$sub_uniqID),]$age)		# mean Korean age: 28
mean(eng[match(unique(eng$sub_uniqID),eng$sub_uniqID),]$age)		# mean English age: 20.95
sd(kor[match(unique(kor$sub_uniqID),kor$sub_uniqID),]$age)		# SD Korean age: 8.29
sd(eng[match(unique(eng$sub_uniqID),eng$sub_uniqID),]$age)		# SD English age: 5.48
range(kor[match(unique(kor$sub_uniqID),kor$sub_uniqID),]$age)	# range of Korean age: 20-54
range(eng[match(unique(eng$sub_uniqID),eng$sub_uniqID),]$age)	# range of English age: 17-43




################----------------------------------------------------------------------------------------------------
## Experiment 1: Signal Detection Theory
################----------------------------------------------------------------------------------------------------
## Signal Detection Theory is not the major thrust of the analysis, since the mixed model analysis below is superior
## We use SDT mainly for comparability with other studies and as additional sanity check


## Define helper function to compute d prime:

get.dprime = function(temp){
	hitrate = sum((temp$chosencondition == "con") & (temp$condition == "con"))
	falsealarms = sum((temp$chosencondition == "con") & (temp$condition == "pan"))	
	hitrate = hitrate / sum(temp$condition == "con")
	falsealarms = falsealarms / sum(temp$condition == "pan")
	hitrate = qnorm(hitrate,lower.tail=F)
	falsealarms = qnorm(falsealarms,lower.tail=F)
	dprime = falsealarms - hitrate	
	return(dprime)
	}


## Load plyr package for ddply function:

library(plyr)



# Compute dprime by subject, items and speaker voice:

dprime_sub = ddply(xdata, .(sub_uniqID), function(df){data.frame(language=unique(df$language),
	dprime=get.dprime(df))})
dprime_item = ddply(xdata, .(keywords), function(df){data.frame(language=unique(df$keywords),
	dprime=get.dprime(df))})
dprime_voices = ddply(xdata, .(speaker), function(df){data.frame(language=unique(df$speaker),
	dprime=get.dprime(df))})



# Inferential stats on d prime:

t.test(dprime ~ language,dprime_sub, var.equal=T)
# difference by language, t(38)=3.64, p<0.001
t.test(dprime_sub[dprime_sub$language=="korean",]$dprime, mu=0, var.equal=T)	
# one-sample t-test against 0 for Korean speakers, t(19)=6.6, p<0.0001
t.test(dprime_sub[dprime_sub$language=="english",]$dprime, mu=0, var.equal=T)
# one-sample t-test against 0 for English speakers, t(19)=4.04, p<0.001
t.test(dprime_sub$dprime,mu=0,var.equal=TRUE)
# one-sample t-test not differentiating by language, t(39)=6.75, p<0.0001
t.test(dprime_item$dprime,mu=0,var.equal=TRUE)
# one-sample t-test by items, t(9)=5.21, p<0.001
t.test(dprime_voices$dprime,mu=0,var.equal=TRUE)
# one sample t-test by voices, t(7)=3.38, p=0.012




################----------------------------------------------------------------------------------------------------
## Experiment 1: Multilevel analysis / mixed models
################----------------------------------------------------------------------------------------------------
## This is the main part of the inferential stats
## We separate the analyses into three phases
## Phase I: Main analysis, testing only for accuracy effect
## Phase II: Secondary analysis (amending the model with control variables)
## Phase III: Additional analyses requested by reviewers


## Load lme4:
## (this analysis was done with lme4 version 0.999999-2)

library(lme4)



## Center continuous predictor variables (important because we're specifically looking at the intercept):

xdata$logRTc = xdata$logRT-mean(xdata$logRT)
xdata$trial_c = xdata$trial-mean(xdata$trial)
xdata$speed_c = (as.numeric(xdata$speed)-1.5)



##########----------- Phase 1 (Main Analysis)
## Intercept only models first to look at overall accuracies:
## (this analysis is delibaretely neglecting all other information)
## (were testing for the intercept here)

## NOT USED IN ACTUAL PAPER:
# xmdl_kor_only = lmer(ACC ~ 1 +  
	# (1|subject)+(1|speaker)+(1|scenario),xdata[xdata$language=="korean",],family="binomial",REML=F)
# summary(xmdl_kor_only)				# log odds: 0.3333, SE=0.1195, p=0.0053
# logit.inv(fixef(xmdl_kor_only)[1])	# predicted accuracy: 58.26%

## NOT USED IN ACTUAL PAPER:
# xmdl_eng_only = lmer(ACC ~ 1 + 
	# (1|subject)+(1|speaker)+(1|scenario),xdata[xdata$language=="english",],family="binomial",REML=F)
# summary(xmdl_eng_only)				# log odds: 0.1196, SE=0.04783, p=0.012
# logit.inv(fixef(xmdl_eng_only)[1])	# predicted accuracy: 52.9%

xmdl_lang_only = lmer(ACC ~ 1 + language + 
	(1|subject)+(1|speaker)+(1|scenario),xdata,family="binomial",REML=F)
summary(xmdl_lang_only)
logit.inv(fixef(xmdl_lang_only)[1])	# predicted accuracy for English: 52.9%
logit.inv(fixef(xmdl_lang_only)[1]+fixef(xmdl_lang_only)[2])	# predicted accuracy for Korean: 58%
exp(fixef(xmdl_lang_only))			# odds ratios, Koreans are 1.23 times more likely to be correct



## Check whether these results hold for the dataset where RT was not excluded:
## (they do, the significance is left intact; hence, the exclusion did not impact the main conclusions)

xmdl_kor_orig = lmer(ACC ~ 1 +  
	(1|subject)+(1|speaker)+(1|scenario),xdata.orig[xdata.orig$language=="korean",],family="binomial",REML=F)
summary(xmdl_kor_orig)				# log odds: 0.3195, SE=0.1168, p=0.0062
logit.inv(fixef(xmdl_kor_orig)[1])	# predicted accuracy: 57.92%

xmdl_eng_orig = lmer(ACC ~ 1 + 
	(1|subject)+(1|speaker)+(1|scenario),xdata.orig[xdata.orig$language=="english",],family="binomial",REML=F)
summary(xmdl_eng_orig)				# log odds: 0.12117, SE=0.04752, p=0.0108
logit.inv(fixef(xmdl_eng_orig)[1])	# predicted accuracy: 53.0%

xmdl_lang_orig = lmer(ACC ~ 1 + language + 
	(1|subject)+(1|speaker)+(1|scenario),xdata.orig,family="binomial",REML=F)
summary(xmdl_lang_orig)
logit.inv(fixef(xmdl_lang_orig)[1])	# predicted accuracy for English: 52.9%
logit.inv(fixef(xmdl_lang_orig)[1]+fixef(xmdl_lang_orig)[2])	# predicted accuracy for Korean: 57.76%
exp(fixef(xmdl_lang_orig))			# odds ratios, Koreans are 1.21 times more likely to be correct



## Because there is a potential concern that the intercept is biased upwards (Roger Mundry, p.c.)
## Here's another way to test accuracy without this problem:

xmdl_kor_new = lmer(chosencondition ~ condition +
	(1|subject)+(1|speaker)+(1|scenario),xdata[xdata$language=="korean",],family="binomial",REML=F)
summary(xmdl_kor_new)				# log odds of pan: 0.6976, SE=0.0756, p<0.0001

xmdl_eng_new = lmer(chosencondition ~ condition +
	(1|subject)+(1|speaker)+(1|scenario),xdata[xdata$language=="english",],family="binomial",REML=F)
summary(xmdl_eng_new)				# log odds of pan: 0.25445, SE=0.07293, p=0.0005

xmdl_lang_new = lmer(chosencondition ~ condition*language + 
	(1|subject)+(1|speaker)+(1|scenario),xdata,family="binomial",REML=F)
summary(xmdl_lang_new)				# significant condition/language interaction (shows that Koreans were better)
# Also, there's a nearly significant effect for koreans having more "pan" responses overall
# Anyway, the analyses replicate with these models where we're not testing for the intercept




##########----------- Phase 2 (Secondary Analysis)
## Look at the influence of "control variables":

xmdl.interact = lmer(ACC ~ (trial_c+logRTc)*language+	# fixed effects
	(1|speaker)+(1|scenario)+(1|subject)+				# random intercepts
	(0+trial_c+logRTc|subject),							# random slopes
	xdata,family="binomial",REML=F)
xmdl.main = lmer(ACC ~ (trial_c+logRTc)+language+		# fixed effects
	(1|speaker)+(1|scenario)+(1|subject)+				# random intercepts
	(0+trial_c+logRTc|subject),							# random slopes
	xdata,family="binomial",REML=F)
xmdl.no = lmer(ACC ~ language+							# fixed effects
	(1|speaker)+(1|scenario)+(1|subject)+				# random intercepts
	(0+trial_c+logRTc|subject),							# random slopes
	xdata,family="binomial",REML=F)
anova(xmdl.interact,xmdl.main,test="Chisq")			# significant: keep model with interaction
anova(xmdl.main,xmdl.no,test="Chisq")				# non-significant
summary(xmdl.interact)								# main model to look at



## For discussion, calculate representative values of slow and fast reaction times:
## Find plausible range for log values to report:

mean(xdata$RT)
exp(mean(xdata$logRT)-0.5);exp(mean(xdata$logRT)+0.5)

# English listeners:
logit.inv(fixef(xmdl.interact)[1]+fixef(xmdl.interact)[2]+fixef(xmdl.interact)[5]+
	-0.5*fixef(xmdl.interact)[3])
logit.inv(fixef(xmdl.interact)[1]+fixef(xmdl.interact)[2]+fixef(xmdl.interact)[5]+
	0.5*fixef(xmdl.interact)[3])

# Korean listeners:
logit.inv(fixef(xmdl.interact)[1]+fixef(xmdl.interact)[2]+
	fixef(xmdl.interact)[4]+fixef(xmdl.interact)[5]+
	-0.5*(fixef(xmdl.interact)[3]+fixef(xmdl.interact)[6]))
logit.inv(fixef(xmdl.interact)[1]+fixef(xmdl.interact)[2]+
	fixef(xmdl.interact)[4]+fixef(xmdl.interact)[5]+
	0.5*(fixef(xmdl.interact)[3]+fixef(xmdl.interact)[6]))



# Descriptive values of speed accuracy trade-off for comparison:

aggregate(logRT ~ ACC*language,xdata,mean)
aggregate(RT ~ ACC*language,xdata,mean)



## Look at difference between "slow" and "fast" conditions:

xmdl_lang_speed_interact = lmer(ACC ~ 1 + language*speed + 
	(1|subject)+(1|speaker)+(1|scenario),xdata,family="binomial",REML=F)
anova(xmdl_lang_speed_interact,xmdl_lang_only)		# x(2)=0.0684, p=0.9664




##########----------- Phase 3 (Reviewer-requested additional analyses)
## A reviewer asked us to check gender effects; hence, we amend the previous model:

xmdl.interact.gender = lmer(ACC ~ language+							# fixed effects
	sex*speaker_gender + 
	(1|speaker)+(1|scenario)+(1|subject),							# random intercepts
	xdata,family="binomial",REML=F)
anova(xmdl_lang_only,xmdl.interact.gender,test="Chisq")				# they are no different
## Hence, we can conclude that gender did not play an effect _at all_ (neither in terms of main effects,
## nor in terms of interaction effects)
summary(xmdl.interact.gender)



## One reviewer wants us to see whether items5-10 are any different:
## Create a new variable that has A = items1-4 and B = items5-10:

relevant_scenarios = levels(xdata$scenario)[5:10]
xdata$scenarioAB = rep("A",nrow(xdata))
xdata[xdata$scenario %in% relevant_scenarios,]$scenarioAB = "B"

## Test this variable in a simple analysis:

xmdl.item510.kor = lmer(ACC ~ scenarioAB + 
	(1|subject)+(1|speaker)+(1|scenario),xdata[xdata$language=="korean",],family="binomial",REML=F)
summary(xmdl.item510.kor)		# AB did not play a role for Koreans

xmdl.item510.eng = lmer(ACC ~ scenarioAB + 
	(1|subject)+(1|speaker)+(1|scenario),xdata[xdata$language=="english",],family="binomial",REML=F)
summary(xmdl.item510.eng)		# AB did not play a role for English

xmdl.item510 = lmer(ACC ~ scenarioAB + language + 
	(1|subject)+(1|speaker)+(1|scenario),xdata,family="binomial",REML=F)
summary(xmdl.item510)



## Another reviewer asked us to make a significance test on the random effects:

xmdl.kor_nosub = lmer(ACC ~ 1 +  
	(1|speaker)+(1|scenario),xdata[xdata$language=="korean",],family="binomial",REML=F)
xmdl.kor_nospeak = lmer(ACC ~ 1 +  
	(1|subject)+(1|scenario),xdata[xdata$language=="korean",],family="binomial",REML=F)
xmdl.kor_noscen = lmer(ACC ~ 1 +  
	(1|subject)+(1|speaker),xdata[xdata$language=="korean",],family="binomial",REML=F)

xmdl.eng_nosub = lmer(ACC ~ 1 +  
	(1|speaker)+(1|scenario),xdata[xdata$language=="english",],family="binomial",REML=F)
xmdl.eng_nospeak = lmer(ACC ~ 1 +  
	(1|subject)+(1|scenario),xdata[xdata$language=="english",],family="binomial",REML=F)		# does not converge properly
xmdl.eng_noscen = lmer(ACC ~ 1 +  
	(1|subject)+(1|speaker),xdata[xdata$language=="english",],family="binomial",REML=F)

anova(xmdl.kor_nosub,xmdl_kor_only)		# x2(1) = 5.2186, p=0.02235
anova(xmdl.kor_nospeak,xmdl_kor_only)	# x2(1) = 36.44, p<0.0001
anova(xmdl.kor_noscen,xmdl_kor_only)	# x2(1) = 9.76172, p=0.005781

anova(xmdl.eng_nosub,xmdl_eng_only)		# x2(1) = 0, p=0.9998
anova(xmdl.eng_nospeak,xmdl_eng_only)	# x2(1) = 1.7479, p=0.1861
anova(xmdl.eng_noscen,xmdl_eng_only)	# x2(1) = 1, p=1



## One reviewer asked us to look at random intercepts / slopes qualitatively, as Hay & Drager (2012) do:

coef(xmdl_kor_only)
coef(xmdl_eng_only)
coef(xmdl_lang_only)		# speaker S6, S7 and S8 were (overall) misinterpreted more likely than not



## For Lucien, take subjects, scenarios and speakers for Korean subset and rank them:

subs_coefs = coef(xmdl_kor_only)$subject
colnames(subs_coefs) = "S"
round(logit.inv(unlist(subs_coefs)[order(unlist(subs_coefs))]),2)
coef(xmdl_kor_only)$scenario		# nothing striking
speak_coefs = coef(xmdl_kor_only)$speaker
colnames(speak_coefs) = "S"
round(logit.inv(unlist(speak_coefs)[order(unlist(speak_coefs))]),2)



## One reviewer asked us to check whether length of stay in the U.S. had an effect:

kor$longstay = rep("short",nrow(kor))
subjects_with_long_stay = c(4,7,11,12,15,17,19,21)
kor[kor$subject %in% subjects_with_long_stay,]$longstay = "long"

xmdl_kor_stay = lmer(ACC ~ longstay +  
	(1|subject)+(1|speaker)+(1|scenario),kor,family="binomial",REML=F)
summary(xmdl_kor_stay)				# log odds: -0.1711, SE=0.0962, p=0.075400
aggregate(ACC ~ longstay,kor,mean)



## One reviewer asked us to check whether dialect played a role:

kor$dialect = rep("seoul",nrow(kor))
dialectal_subjects = c(6,7,8,9,10,12,13,15,18)
kor[kor$subject %in% dialectal_subjects,]$dialect = "other"

xmdl_kor_dialect = lmer(ACC ~ dialect +  
	(1|subject)+(1|speaker)+(1|scenario),kor,family="binomial",REML=F)
summary(xmdl_kor_dialect)				# log odds: -0.17195, SE=0.9439, p=0.068517
aggregate(ACC ~ dialect,kor,mean)



## One reviewer asked us to check whether bilingualism played a role:

monolinguals = c(2,3,4,6,10,12,13,15,16,17,20)
bilinguals = c(1,5,7,9,11,18,21,22,23)

eng$bilingualism = "mono"
eng[eng$subject %in% bilinguals,]$bilingualism = "biling"
xmdl_eng_biling = lmer(ACC ~ bilingualism +  
	(1|subject)+(1|speaker)+(1|scenario),eng,family="binomial",REML=F)
summary(xmdl_eng_biling)	




################----------------------------------------------------------------------------------------------------
################ Analysis of Experiment 1: Publication-ready plots
################----------------------------------------------------------------------------------------------------



library(plyr)

## Create accuracy subsets:

sub_acc=ddply(xdata, .(sub_uniqID), function(df){data.frame(language=unique(df$language),
	ACC=mean(df$ACC),SD=sd(df$ACC),No=length(df$ACC))})
sub_acc$SE = sub_acc$SD/sqrt(sub_acc$No)
sub_acc = sub_acc[order(sub_acc$language,sub_acc$ACC),]
sub_acc = sub_acc[order(sub_acc$language,decreasing=TRUE),]



## Plotting accuracy:

quartz("",12,5);par(mai=c(1,1.5,0.5,0.5))
emptyplot(c(1:20,22:(nrow(sub_acc)+1)),sub_acc$ACC,ylim=c(0,1))
points(c(1:20,22:(nrow(sub_acc)+1)),sub_acc$ACC,pch=19)
arrows(x0=c(1:20,22:(nrow(sub_acc)+1)),y0=sub_acc$ACC-sub_acc$SE,
	y1=sub_acc$ACC+sub_acc$SE,angle=90,code=3,length=0.05)
abline(h=0.5,lty="dashed",lwd=2)
abline(v=21,lwd=2)
axis(side=2,at=seq(0,1,0.2),labels=seq(0,1,0.2),las=2,font=2,cex.axis=1.25)
axis(side=1,at=c(1,10.5,20),
	labels=c("S1","...","S20"))
axis(side=1,at=c(22,32,nrow(sub_acc)+1),
	labels=c("S21","...","S40"))
axis(side=1,at=c(10.5,32),
	labels=c("Korean listeners","English listeners"),
	tick=F,line=2,cex.axis=1.5,font=2)
mtext(side=2,"Accuracy",cex=1.5,font=2,line=3.5)


